/* Based on example.c from libshout3.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <shout/shout.h>

int main(int argc, char ** argv)
{
	shout_t *shout;
	char buff[4096];
	long read, ret;

	if (argc != 5) {
		fprintf(stderr,
			"Usage: oggshout hostname port password mount\n");
		return 2;
	}

	shout_init();

	if (!(shout = shout_new())) {
		fprintf(stderr, "Could not allocate shout_t\n");
		return 1;
	}

	if (shout_set_host(shout, argv[1]) != SHOUTERR_SUCCESS) {
		fprintf(stderr, "Error setting hostname: %s\n",
			shout_get_error(shout));
		return 1;
	}

	if (shout_set_protocol(shout, SHOUT_PROTOCOL_HTTP) != SHOUTERR_SUCCESS) {
		fprintf(stderr, "Error setting protocol: %s\n",
			shout_get_error(shout));
		return 1;
	}

	if (shout_set_port(shout, atoi(argv[2])) != SHOUTERR_SUCCESS) {
		fprintf(stderr, "Error setting port: %s\n",
			shout_get_error(shout));
		return 1;
	}

	if (shout_set_password(shout, argv[3]) != SHOUTERR_SUCCESS) {
		fprintf(stderr, "Error setting password: %s\n",
			shout_get_error(shout));
		return 1;
	}
	if (shout_set_mount(shout, argv[4]) != SHOUTERR_SUCCESS) {
		fprintf(stderr, "Error setting mount: %s\n",
			shout_get_error(shout));
		return 1;
	}

	if (shout_set_user(shout, "source") != SHOUTERR_SUCCESS) {
		fprintf(stderr, "Error setting user: %s\n",
			shout_get_error(shout));
		return 1;
	}

	if (shout_set_format(shout, SHOUT_FORMAT_OGG) != SHOUTERR_SUCCESS) {
		fprintf(stderr, "Error setting user: %s\n",
			shout_get_error(shout));
		return 1;
	}

	if (shout_open(shout) == SHOUTERR_SUCCESS) {
		fprintf(stderr, "Connected to server...\n");
		while ((read = fread(buff, 1, sizeof(buff), stdin)) > 0) {
			ret = shout_send(shout, buff, read);
			if (ret != SHOUTERR_SUCCESS) {
				fprintf(stderr, "Send error: %s\n",
					shout_get_error(shout));
				break;
			}
			shout_sync(shout);
		}
	} else {
		fprintf(stderr, "Error connecting: %s\n",
			shout_get_error(shout));
	}

	shout_close(shout);

	shout_shutdown();

	return 0;
}
